@@ -159,7 +159,7 @@ class BatchClassificationAnnotator(PersistentAnnotator[str]):
         n_discard_examples = self.n_examples - len(self.examples)
         n_labeled = self.no_labeled_examples() - n_discard_examples
         n_examples = len(self.examples)
-        self.el_view[0].value = f"<b>Current batch</b>: {self.current_index} / {math.ceil(n_examples / self.batch_size)}. <b>Progress</b>: {round(n_labeled * 100 / max(n_examples, 1), 2)}% ({n_labeled} / {n_examples})"
+        self.el_view[0].value = f"<b>Current batch</b>: {math.ceil(self.current_index / self.batch_size)} / {math.ceil(n_examples / self.batch_size)}. <b>Progress</b>: {round(n_labeled * 100 / max(n_examples, 1), 2)}% ({n_labeled} / {n_examples})"
 
     def on_clear(self, _btn: widgets.Button) -> None:
         # somehow calling super does not work
